==> jc-1.4.0.tar.gz: gnu/java/security/ber/BERReader.h <==
// public class gnu.java.security.ber.BERReader

// class file dependencies
// @dep_class 8d1e497fc84b4bcc gnu_java_security_ber_BERReader
// @dep_class 72b2c34b8fa2f145 gnu_java_security_der_DERReader
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_der_DERReader

#include "gnu/java/security/der/DERReader.h"

#ifndef _JC_gnu_java_security_ber_BERReader_H_
#define _JC_gnu_java_security_ber_BERReader_H_

// Forward structure declarations
struct _jc_gnu_java_security_der_DERValue$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_security_ber_BERReader$sub_refs	_jc_gnu_java_security_ber_BERReader$sub_refs;
typedef struct _jc_gnu_java_security_ber_BERReader$sub_nonrefs	_jc_gnu_java_security_ber_BERReader$sub_nonrefs;
typedef struct _jc_gnu_java_security_ber_BERReader$refs	_jc_gnu_java_security_ber_BERReader$refs;
typedef struct _jc_gnu_java_security_ber_BERReader$nonrefs	_jc_gnu_java_security_ber_BERReader$nonrefs;
typedef struct _jc_gnu_java_security_ber_BERReader$object	_jc_gnu_java_security_ber_BERReader$object;

typedef const struct _jc_gnu_java_security_ber_BERReader$vmethods	_jc_gnu_java_security_ber_BERReader$vmethods;
typedef const struct _jc_gnu_java_security_ber_BERReader$vtable	_jc_gnu_java_security_ber_BERReader$vtable;
typedef const struct _jc_gnu_java_security_ber_BERReader$vtype	_jc_gnu_java_security_ber_BERReader$vtype;

// Constructors
extern void _jc_gnu_java_security_ber_BERReader$method$_init$3887600c17c5e554(_jc_env *, struct _jc_gnu_java_security_ber_BERReader$object *, struct _jc_java_io_InputStream$object *);
extern void _jc_gnu_java_security_ber_BERReader$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_ber_BERReader$object *, struct _jc_byte_array *);
extern void _jc_gnu_java_security_ber_BERReader$method$_init$4ff4a7925ef7b06c(_jc_env *, struct _jc_gnu_java_security_ber_BERReader$object *, struct _jc_byte_array *, jint, jint);

// Virtual methods
extern jint _jc_gnu_java_security_ber_BERReader$method$peek$73fe3352195546d5(_jc_env *, struct _jc_gnu_java_security_ber_BERReader$object *);
extern struct _jc_gnu_java_security_der_DERValue$object *_jc_gnu_java_security_ber_BERReader$method$read$97cabf4c92410204(_jc_env *, struct _jc_gnu_java_security_ber_BERReader$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_ber_BERReader$method_info$peek$73fe3352195546d5;
extern _jc_method _jc_gnu_java_security_ber_BERReader$method_info$read$97cabf4c92410204;

// Virtual methods structure
struct _jc_gnu_java_security_ber_BERReader$vmethods {
	jint	(*peek$73fe3352195546d5)(_jc_env *, struct _jc_gnu_java_security_ber_BERReader$object *);
	struct _jc_gnu_java_security_der_DERValue$object	*(*read$97cabf4c92410204)(_jc_env *, struct _jc_gnu_java_security_ber_BERReader$object *);
};

// Vtable
struct _jc_gnu_java_security_ber_BERReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_der_DERReader$vmethods	gnu_java_security_der_DERReader;
	_jc_gnu_java_security_ber_BERReader$vmethods	gnu_java_security_ber_BERReader;
};

// Vtype
struct _jc_gnu_java_security_ber_BERReader$vtype {
	_jc_type			type;
	_jc_gnu_java_security_ber_BERReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_ber_BERReader$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_ber_BERReader$refs {
    _jc_gnu_java_security_ber_BERReader$sub_refs	gnu_java_security_ber_BERReader;
    _jc_gnu_java_security_der_DERReader$sub_refs	gnu_java_security_der_DERReader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_ber_BERReader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_ber_BERReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_der_DERReader$sub_nonrefs	gnu_java_security_der_DERReader;
    _jc_gnu_java_security_ber_BERReader$sub_nonrefs	gnu_java_security_ber_BERReader;
};

// Object instance structure
struct _jc_gnu_java_security_ber_BERReader$object {
	_jc_gnu_java_security_ber_BERReader$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_ber_BERReader$vtype	*vtype;
	_jc_gnu_java_security_ber_BERReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_ber_BERReader$vtype _jc_gnu_java_security_ber_BERReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_ber_BERReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_ber_BERReader$class_object;

#endif	/* _JC_gnu_java_security_ber_BERReader_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/ber/BERReader.h <==
// public class gnu.java.security.ber.BERReader

// class file dependencies
// @dep_class 8d1e497fc84b4bcc gnu_java_security_ber_BERReader
// @dep_class 78ef52e48159b870 gnu_java_security_der_DERReader
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_der_DERReader

#include "gnu/java/security/der/DERReader.h"

#ifndef _JC_gnu_java_security_ber_BERReader_H_
#define _JC_gnu_java_security_ber_BERReader_H_

// Forward structure declarations
struct _jc_gnu_java_security_der_DERValue$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_security_ber_BERReader$sub_refs	_jc_gnu_java_security_ber_BERReader$sub_refs;
typedef struct _jc_gnu_java_security_ber_BERReader$sub_nonrefs	_jc_gnu_java_security_ber_BERReader$sub_nonrefs;
typedef struct _jc_gnu_java_security_ber_BERReader$refs	_jc_gnu_java_security_ber_BERReader$refs;
typedef struct _jc_gnu_java_security_ber_BERReader$nonrefs	_jc_gnu_java_security_ber_BERReader$nonrefs;
typedef struct _jc_gnu_java_security_ber_BERReader$object	_jc_gnu_java_security_ber_BERReader$object;

typedef const struct _jc_gnu_java_security_ber_BERReader$vmethods	_jc_gnu_java_security_ber_BERReader$vmethods;
typedef const struct _jc_gnu_java_security_ber_BERReader$vtable	_jc_gnu_java_security_ber_BERReader$vtable;
typedef const struct _jc_gnu_java_security_ber_BERReader$vtype	_jc_gnu_java_security_ber_BERReader$vtype;

// Constructors
extern void _jc_gnu_java_security_ber_BERReader$method$_init$3887600c17c5e554(_jc_env *, struct _jc_gnu_java_security_ber_BERReader$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_ber_BERReader$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_ber_BERReader$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_ber_BERReader$method$_init$4ff4a7925ef7b06c(_jc_env *, struct _jc_gnu_java_security_ber_BERReader$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_security_ber_BERReader$method$peek$73fe3352195546d5(_jc_env *, struct _jc_gnu_java_security_ber_BERReader$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_java_security_der_DERValue$object *_jc_gnu_java_security_ber_BERReader$method$read$97cabf4c92410204(_jc_env *, struct _jc_gnu_java_security_ber_BERReader$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_ber_BERReader$method_info$peek$73fe3352195546d5;
extern _jc_method _jc_gnu_java_security_ber_BERReader$method_info$read$97cabf4c92410204;

// Virtual methods structure
struct _jc_gnu_java_security_ber_BERReader$vmethods {
	jint	(*peek$73fe3352195546d5)(_jc_env *, struct _jc_gnu_java_security_ber_BERReader$object *) _JC_JCNI_ATTR;
	struct _jc_gnu_java_security_der_DERValue$object	*(*read$97cabf4c92410204)(_jc_env *, struct _jc_gnu_java_security_ber_BERReader$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_ber_BERReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_der_DERReader$vmethods	gnu_java_security_der_DERReader;
	_jc_gnu_java_security_ber_BERReader$vmethods	gnu_java_security_ber_BERReader;
};

// Vtype
struct _jc_gnu_java_security_ber_BERReader$vtype {
	_jc_type			type;
	_jc_gnu_java_security_ber_BERReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_ber_BERReader$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_ber_BERReader$refs {
    _jc_gnu_java_security_ber_BERReader$sub_refs	gnu_java_security_ber_BERReader;
    _jc_gnu_java_security_der_DERReader$sub_refs	gnu_java_security_der_DERReader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_ber_BERReader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_ber_BERReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_der_DERReader$sub_nonrefs	gnu_java_security_der_DERReader;
    _jc_gnu_java_security_ber_BERReader$sub_nonrefs	gnu_java_security_ber_BERReader;
};

// Object instance structure
struct _jc_gnu_java_security_ber_BERReader$object {
	_jc_gnu_java_security_ber_BERReader$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_ber_BERReader$vtype	*vtype;
	_jc_gnu_java_security_ber_BERReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_ber_BERReader$vtype _jc_gnu_java_security_ber_BERReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_ber_BERReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_ber_BERReader$class_object;

#endif	/* _JC_gnu_java_security_ber_BERReader_H_ */
